"""
Example FastAPI application for testing the postman exporter.
"""

from fastapi import FastAPI, HTTPException
from pydantic import BaseModel
from typing import List, Optional

app = FastAPI(
    title="Example API",
    description="A sample FastAPI application for testing the postman exporter",
    version="1.0.0",
    contact={
        "name": "API Support",
        "email": "support@example.com",
    },
    license_info={
        "name": "MIT",
        "url": "https://opensource.org/licenses/MIT",
    },
)

# Pydantic models
class Item(BaseModel):
    id: Optional[int] = None
    name: str
    description: Optional[str] = None
    price: float
    is_available: bool = True

class User(BaseModel):
    id: Optional[int] = None
    username: str
    email: str
    full_name: Optional[str] = None
    is_active: bool = True

# In-memory storage for demo
items_db = []
users_db = []

@app.get("/")
def read_root():
    """Root endpoint returning API information."""
    return {
        "message": "Welcome to Example API",
        "version": "1.0.0",
        "docs": "/docs"
    }

@app.get("/health")
def health_check():
    """Health check endpoint."""
    return {"status": "healthy", "timestamp": "2024-01-01T00:00:00Z"}

# Items endpoints
@app.get("/items/", response_model=List[Item])
def get_items(skip: int = 0, limit: int = 10):
    """Get all items with pagination."""
    return items_db[skip : skip + limit]

@app.get("/items/{item_id}", response_model=Item)
def get_item(item_id: int):
    """Get a specific item by ID."""
    if item_id >= len(items_db):
        raise HTTPException(status_code=404, detail="Item not found")
    return items_db[item_id]

@app.post("/items/", response_model=Item)
def create_item(item: Item):
    """Create a new item."""
    item.id = len(items_db)
    items_db.append(item)
    return item

@app.put("/items/{item_id}", response_model=Item)
def update_item(item_id: int, item: Item):
    """Update an existing item."""
    if item_id >= len(items_db):
        raise HTTPException(status_code=404, detail="Item not found")
    item.id = item_id
    items_db[item_id] = item
    return item

@app.delete("/items/{item_id}")
def delete_item(item_id: int):
    """Delete an item."""
    if item_id >= len(items_db):
        raise HTTPException(status_code=404, detail="Item not found")
    deleted_item = items_db.pop(item_id)
    return {"message": f"Item {deleted_item.name} deleted successfully"}

# Users endpoints
@app.get("/users/", response_model=List[User])
def get_users(skip: int = 0, limit: int = 10):
    """Get all users with pagination."""
    return users_db[skip : skip + limit]

@app.get("/users/{user_id}", response_model=User)
def get_user(user_id: int):
    """Get a specific user by ID."""
    if user_id >= len(users_db):
        raise HTTPException(status_code=404, detail="User not found")
    return users_db[user_id]

@app.post("/users/", response_model=User)
def create_user(user: User):
    """Create a new user."""
    user.id = len(users_db)
    users_db.append(user)
    return user

@app.put("/users/{user_id}", response_model=User)
def update_user(user_id: int, user: User):
    """Update an existing user."""
    if user_id >= len(users_db):
        raise HTTPException(status_code=404, detail="User not found")
    user.id = user_id
    users_db[user_id] = user
    return user

@app.delete("/users/{user_id}")
def delete_user(user_id: int):
    """Delete a user."""
    if user_id >= len(users_db):
        raise HTTPException(status_code=404, detail="User not found")
    deleted_user = users_db.pop(user_id)
    return {"message": f"User {deleted_user.username} deleted successfully"}

# Search endpoint
@app.get("/search/")
def search_items(q: str, category: Optional[str] = None):
    """Search items by query and optional category."""
    results = []
    for item in items_db:
        if q.lower() in item.name.lower():
            if category is None or category.lower() in item.description.lower():
                results.append(item)
    return {"query": q, "category": category, "results": results, "count": len(results)}

if __name__ == "__main__":
    import uvicorn
    uvicorn.run(app, host="0.0.0.0", port=8000) 