"""
Simple test script to verify the fastapi_postman_exporter package functionality.
"""

import json
import tempfile
from pathlib import Path

from fastapi import FastAPI
from fastapi_postman_exporter import generate_postman_from_app, check_openapi2postmanv2_installed

def test_basic_functionality():
    """Test basic functionality of the exporter."""
    print("Testing FastAPI Postman Exporter...")
    
    # Create a simple FastAPI app
    app = FastAPI(
        title="Test API",
        description="A test API for the exporter",
        version="1.0.0"
    )
    
    @app.get("/")
    def read_root():
        return {"message": "Hello World"}
    
    @app.get("/items/{item_id}")
    def read_item(item_id: int):
        return {"item_id": item_id}
    
    # Test CLI tool check
    try:
        check_openapi2postmanv2_installed()
        print("✅ openapi2postmanv2 CLI tool is available")
    except RuntimeError as e:
        print(f"❌ {e}")
        print("Please install openapi2postmanv2: npm install -g openapi2postmanv2")
        return False
    
    # Test export functionality
    try:
        with tempfile.NamedTemporaryFile(mode='w', suffix='.json', delete=False) as temp_file:
            output_path = temp_file.name
        
        generate_postman_from_app(app, output_path)
        
        # Verify the output file exists and contains valid JSON
        if Path(output_path).exists():
            with open(output_path, 'r') as f:
                collection = json.load(f)
            
            # Basic validation of Postman collection structure
            if 'info' in collection and 'item' in collection:
                print("✅ Successfully generated Postman collection")
                print(f"   Collection name: {collection['info'].get('name', 'Unknown')}")
                print(f"   Number of requests: {len(collection['item'])}")
                
                # Clean up
                Path(output_path).unlink()
                return True
            else:
                print("❌ Generated file is not a valid Postman collection")
                return False
        else:
            print("❌ Output file was not created")
            return False
            
    except Exception as e:
        print(f"❌ Error during export: {e}")
        return False

if __name__ == "__main__":
    success = test_basic_functionality()
    if success:
        print("\n🎉 All tests passed! The package is working correctly.")
    else:
        print("\n💥 Some tests failed. Please check the error messages above.")
        exit(1) 