"""
Test script to verify the package works from any directory.
Run this from your FastAPI app directory after installing the package.
"""

import sys
import os

def test_package_import():
    """Test if the package can be imported."""
    try:
        from fastapi_postman_exporter import generate_postman_from_app, check_openapi2postmanv2_installed
        print("✅ Package imported successfully!")
        return True
    except ImportError as e:
        print(f"❌ Could not import package: {e}")
        print("\nTo fix this, install the package from the local path:")
        print("pip install -e /Users/ai/gurminder/famQR/fastapipostmangen")
        return False

def test_cli_tool():
    """Test if the CLI tool is available."""
    try:
        from fastapi_postman_exporter import check_openapi2postmanv2_installed
        check_openapi2postmanv2_installed()
        print("✅ openapi2postmanv2 CLI tool is available!")
        return True
    except Exception as e:
        print(f"❌ CLI tool not available: {e}")
        return False

def test_with_sample_app():
    """Test with a sample FastAPI app."""
    try:
        from fastapi import FastAPI
        from fastapi_postman_exporter import generate_postman_from_app
        
        # Create a simple test app
        app = FastAPI(title="Test API", version="1.0.0")
        
        @app.get("/")
        def read_root():
            return {"message": "Hello World"}
        
        @app.get("/test/{item_id}")
        def read_item(item_id: int):
            return {"item_id": item_id}
        
        # Export to Postman
        output_file = "test_collection.json"
        generate_postman_from_app(app, output_file)
        
        # Check if file was created
        if os.path.exists(output_file):
            file_size = os.path.getsize(output_file)
            print(f"✅ Successfully created Postman collection: {output_file} ({file_size} bytes)")
            
            # Clean up
            os.remove(output_file)
            return True
        else:
            print("❌ Collection file was not created")
            return False
            
    except Exception as e:
        print(f"❌ Error during export: {e}")
        return False

if __name__ == "__main__":
    print("🧪 Testing FastAPI Postman Exporter package...")
    print(f"Current directory: {os.getcwd()}")
    print(f"Python path: {sys.path[:3]}...")  # Show first 3 entries
    
    # Run tests
    tests = [
        ("Package Import", test_package_import),
        ("CLI Tool Check", test_cli_tool),
        ("Sample Export", test_with_sample_app),
    ]
    
    results = []
    for test_name, test_func in tests:
        print(f"\n--- {test_name} ---")
        result = test_func()
        results.append((test_name, result))
    
    # Summary
    print("\n" + "="*50)
    print("TEST SUMMARY:")
    for test_name, result in results:
        status = "✅ PASS" if result else "❌ FAIL"
        print(f"  {test_name}: {status}")
    
    all_passed = all(result for _, result in results)
    if all_passed:
        print("\n🎉 All tests passed! The package is ready to use.")
        print("\nYou can now use it in your FastAPI app:")
        print("""
from fastapi_postman_exporter import generate_postman_from_app
from your_app import app

# Export your app to Postman
generate_postman_from_app(app, "your_collection.json")
        """)
    else:
        print("\n💥 Some tests failed. Please check the error messages above.")
        print("\nInstallation instructions:")
        print("1. Make sure you're in your FastAPI app directory")
        print("2. Run: pip install -e /Users/ai/gurminder/famQR/fastapipostmangen")
        print("3. Make sure openapi2postmanv2 is installed: npm install -g openapi2postmanv2") 